|PyPI| |Docs| |Tests| |Coverage| |Downloads| |Black| |Slack|

`Installation`_ | `Documentation`_ | `Tutorials`_ | `Research-Article`_

|IMG1|

.. |PyPI| image:: https://img.shields.io/pypi/v/scarf.svg
         :target: https://pypi.org/project/scarf
.. |Docs| image:: https://readthedocs.org/projects/scarf/badge/?version=latest
         :target: https://scarf.readthedocs.io
.. |Tests| image:: https://github.com/parashardhapola/scarf/actions/workflows/pytest.yml/badge.svg
          :target: https://github.com/parashardhapola/scarf/actions/workflows/pytest.yml
.. |Coverage| image:: https://codecov.io/gh/parashardhapola/scarf/branch/master/graph/badge.svg?token=ZvJXuYq3pd
             :target: https://codecov.io/gh/parashardhapola/scarf
.. |Downloads| image:: https://pepy.tech/badge/scarf
              :target: https://pepy.tech/project/scarf
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
          :target: https://github.com/psf/black
.. |Slack| image:: https://img.shields.io/badge/Slack-4A154B?style=for-the-badge&logo=slack&logoColor=white
          :target: https://scarf-group.slack.com/archives/C0418C7RXU4

.. |IMG1| image:: https://raw.githubusercontent.com/parashardhapola/scarf/master/docs/source/logo_wide.png
         :target: https://github.com/parashardhapola/scarf

Analyze large-scale (aka atlas-scale) single-cell genomics datasets with very low memory requirement.

.. _Installation: https://scarf.readthedocs.io/en/latest/install.html
.. _Documentation: http://scarf.rtfd.io
.. _Tutorials: https://scarf.readthedocs.io/en/latest/vignettes/basic_tutorial_scRNAseq.html
.. _Research-Article: https://www.nature.com/articles/s41467-022-32097-3
